@@ -89,6 +89,8 @@ ExternalProgramPaths ExternalSextractorSolver::getMacHomebrewPaths()
     };
 }
 
+//This one is now obsolete due to StellarSolver's acceptance since KStars will no longer needs an internal
+//build of astrometry.net on Macs.  I will delete this later.
 ExternalProgramPaths ExternalSextractorSolver::getMacInternalPaths()
 {
     return ExternalProgramPaths
@@ -941,7 +943,11 @@ void ExternalSextractorSolver::logSextractor()
                 if (file.open(QIODevice::Append | QIODevice::Text))
                 {
                     QTextStream outstream(&file);
-                    outstream << cleanedString << endl;
+                    #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+                        outstream << cleanedString << Qt::endl;
+                    #else
+                        outstream << cleanedString << endl;
+                    #endif
                     file.close();
                 }
                 else
@@ -965,7 +971,11 @@ void ExternalSextractorSolver::logSolver()
                 if (file.open(QIODevice::Append | QIODevice::Text))
                 {
                     QTextStream outstream(&file);
-                    outstream << solverLine << endl;
+                    #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+                        outstream << solverLine << Qt::endl;
+                    #else
+                        outstream << solverLine << endl;
+                    #endif
                     file.close();
                 }
                 else
@@ -996,7 +1006,7 @@ int ExternalSextractorSolver::getStarsFromXYLSFile()
     long nelements[1000];
     long jj, nrows, kk;
 
-    if (fits_open_diskfile(&new_fptr, sextractorFilePath.toLatin1(), READONLY, &status))
+    if (fits_open_diskfile(&new_fptr, sextractorFilePath.toLocal8Bit(), READONLY, &status))
     {
         fits_report_error(stderr, status);
         fits_get_errstatus(status, error_status);
@@ -1105,7 +1115,7 @@ int ExternalSextractorSolver::getStarsFromXYLSFile()
             theta = qRadiansToDegrees(atan(xy / (lambda1 - yy)));
         }
 
-        FITSImage::Star star = {starx, stary, mag, flux, peak, HFR, a, b, theta, 0, 0};
+        FITSImage::Star star = {starx, stary, mag, flux, peak, HFR, a, b, theta, 0, 0, (int)(a*b*3.14)};
 
         m_ExtractedStars.append(star);
     }
@@ -1362,7 +1372,7 @@ int ExternalSextractorSolver::writeSextractorTable()
             fileToProcessIsTempFile = true;
         }
 
-        if (fits_open_diskfile(&new_fptr, fileToProcess.toLatin1(), READWRITE, &status))
+        if (fits_open_diskfile(&new_fptr, fileToProcess.toLocal8Bit(), READWRITE, &status))
         {
             fits_report_error(stderr, status);
             return status;
@@ -1380,7 +1390,7 @@ int ExternalSextractorSolver::writeSextractorTable()
         if(sextractorFile.exists())
             sextractorFile.remove();
 
-        if (fits_create_file(&new_fptr, sextractorFilePath.toLatin1(), &status))
+        if (fits_create_file(&new_fptr, sextractorFilePath.toLocal8Bit(), &status))
         {
             fits_report_error(stderr, status);
             return status;
@@ -1458,7 +1468,7 @@ int ExternalSextractorSolver::writeSextractorTable()
 //This was copied and pasted and modified from ImageToFITS in fitsdata in KStars
 int ExternalSextractorSolver::saveAsFITS()
 {
-    QFileInfo fileInfo(fileToProcess.toLatin1());
+    QFileInfo fileInfo(fileToProcess);
     QString newFilename = m_BasePath + "/" + m_BaseName + ".fits";
 
     int status = 0;
@@ -1490,7 +1500,7 @@ int ExternalSextractorSolver::saveAsFITS()
     nelements = m_Statistics.samples_per_channel * channels;
 
     /* Create a new File, overwriting existing*/
-    if (fits_create_file(&new_fptr, newFilename.toLatin1(), &status))
+    if (fits_create_file(&new_fptr, newFilename.toLocal8Bit(), &status))
     {
         fits_report_error(stderr, status);
         return status;
@@ -1604,7 +1614,7 @@ int ExternalSextractorSolver::loadWCS()
 
     fitsfile *fptr { nullptr };
 
-    if (fits_open_diskfile(&fptr, solutionFile.toLatin1(), READONLY, &status))
+    if (fits_open_diskfile(&fptr, solutionFile.toLocal8Bit(), READONLY, &status))
     {
         char errmsg[512];
         fits_get_errstatus(status, errmsg);
